@@ -1,4 +1,4 @@
-/* $Id: thread.cpp 135976 2020-02-04 10:35:17Z bird $ */
+/* $Id: thread.cpp 136258 2020-02-21 22:58:42Z bird $ */
 /** @file
  * IPRT - Threads, common routines.
  */
@@ -663,12 +663,14 @@ DECLHIDDEN(void) rtThreadTerminate(PRTTHREADINT pThread, int rc)
 {
     Assert(pThread->cRefs >= 1);
 
-#ifdef IPRT_WITH_GENERIC_TLS
     /*
      * Destroy TLS entries.
      */
+#ifdef IPRT_WITH_GENERIC_TLS
     rtThreadTlsDestruction(pThread);
-#endif /* IPRT_WITH_GENERIC_TLS */
+#elif defined(RT_OS_WINDOWS) && defined(IN_RING3)
+    rtThreadWinTlsDestruction();
+#endif
 
     /*
      * Set the rc, mark it terminated and signal anyone waiting.
