@@ -1,4 +1,4 @@
-/* $Id: waitqueue-r0drv-linux.h 135976 2020-02-04 10:35:17Z bird $ */
+/* $Id: waitqueue-r0drv-linux.h 139853 2020-08-11 19:53:38Z bird $ */
 /** @file
  * IPRT - Linux Ring-0 Driver Helpers for Abstracting Wait Queues,
  */
@@ -48,9 +48,7 @@
 typedef struct RTR0SEMLNXWAIT
 {
     /** The wait queue entry. */
-#if LINUX_VERSION_CODE > KERNEL_VERSION(4, 13, 0) \
-  || defined(CONFIG_SUSE_VERSION) && CONFIG_SUSE_VERSION == 12 && CONFIG_SUSE_PATCHLEVEL == 4 \
-  || defined(CONFIG_SUSE_VERSION) && CONFIG_SUSE_VERSION == 15
+#if RTLNX_VER_MIN(4,13,0) || RTLNX_SUSE_MAJ_PREREQ(12, 4) || RTLNX_SUSE_MAJ_PREREQ(15, 0)
     wait_queue_entry_t WaitQE;
 #else
     wait_queue_t    WaitQE;
@@ -183,7 +181,7 @@ DECLINLINE(int) rtR0SemLnxWaitInit(PRTR0SEMLNXWAIT pWait, uint32_t fFlags, uint6
     /*
      * Initialize the wait queue related bits.
      */
-#if LINUX_VERSION_CODE >= KERNEL_VERSION(2, 5, 39)
+#if RTLNX_VER_MIN(2,5,39)
     init_wait((&pWait->WaitQE));
 #else
     RT_ZERO(pWait->WaitQE);
